export class TemplateManager {
    constructor(viewContainerRef, initialViewContext) {
        this.viewContainerRef = viewContainerRef;
        this.templateCache = new Map();
        this.viewCache = new Map();
        this.viewContext = Object.assign({}, initialViewContext);
    }
    updateViewContext(viewContextSlice) {
        Object.entries(viewContextSlice).forEach(([key, value]) => {
            this.viewContext[key] = value;
        });
    }
    addTemplateRef(name, templateRef) {
        assertTemplate(name, templateRef);
        this.templateCache.set(name, templateRef);
    }
    insertEmbeddedView(name) {
        if (this.templateCache.has(name)) {
            this.viewContainerRef.detach();
            if (this.viewCache.has(name)) {
                this.viewContainerRef.insert(this.viewCache.get(name));
            }
            else {
                const newView = this.viewContainerRef.createEmbeddedView(this.templateCache.get(name), this.viewContext);
                this.viewCache.set(name, newView);
            }
        }
    }
    destroy() {
        this.viewCache.forEach(embeddedView => embeddedView === null || embeddedView === void 0 ? void 0 : embeddedView.destroy());
        this.viewContainerRef.clear();
    }
}
function assertTemplate(property, templateRef) {
    const isTemplateRefOrNull = !!(!templateRef || templateRef.createEmbeddedView);
    if (!isTemplateRefOrNull) {
        throw new Error(`${property} must be a TemplateRef, but received something else.`);
    }
    return isTemplateRefOrNull;
}
//# sourceMappingURL=template-manager.js.map