import { __assign, __read } from "tslib";
var TemplateManager = /** @class */ (function () {
    function TemplateManager(viewContainerRef, initialViewContext) {
        this.viewContainerRef = viewContainerRef;
        this.templateCache = new Map();
        this.viewCache = new Map();
        this.viewContext = __assign({}, initialViewContext);
    }
    TemplateManager.prototype.updateViewContext = function (viewContextSlice) {
        var _this = this;
        Object.entries(viewContextSlice).forEach(function (_a) {
            var _b = __read(_a, 2), key = _b[0], value = _b[1];
            _this.viewContext[key] = value;
        });
    };
    TemplateManager.prototype.addTemplateRef = function (name, templateRef) {
        assertTemplate(name, templateRef);
        this.templateCache.set(name, templateRef);
    };
    TemplateManager.prototype.insertEmbeddedView = function (name) {
        if (this.templateCache.has(name)) {
            this.viewContainerRef.detach();
            if (this.viewCache.has(name)) {
                this.viewContainerRef.insert(this.viewCache.get(name));
            }
            else {
                var newView = this.viewContainerRef.createEmbeddedView(this.templateCache.get(name), this.viewContext);
                this.viewCache.set(name, newView);
            }
        }
    };
    TemplateManager.prototype.destroy = function () {
        this.viewCache.forEach(function (embeddedView) { return embeddedView === null || embeddedView === void 0 ? void 0 : embeddedView.destroy(); });
        this.viewContainerRef.clear();
    };
    return TemplateManager;
}());
export { TemplateManager };
function assertTemplate(property, templateRef) {
    var isTemplateRefOrNull = !!(!templateRef || templateRef.createEmbeddedView);
    if (!isTemplateRefOrNull) {
        throw new Error(property + " must be a TemplateRef, but received something else.");
    }
    return isTemplateRefOrNull;
}
//# sourceMappingURL=template-manager.js.map