import { tap } from 'rxjs/operators';
import { ɵmarkDirty as markDirty } from '@angular/core';
/**
 * Native Strategy
 * @description
 *
 * - mFC - `cdRef.markForCheck`
 *
 * This strategy mirrors Angular's built-in `async` pipe.
 * This means for every emitted value `ChangeDetectorRef#markForCheck` is called.
 *
 * | Name        | ZoneLess | Render Method | ScopedCoalescing | Scheduling | Chunked |
 * |-------------| ---------| --------------| ---------------- | ---------- |-------- |
 * | `native`    | ❌       | mFC           | ❌                | ❌         | ❌      |
 *
 * @param config { RenderStrategyFactoryConfig } - The values this strategy needs to get calculated.
 * @return {RenderStrategy} - The calculated strategy
 *
 */
export function createNativeStrategy(config) {
    var component = config.cdRef.context;
    return {
        name: 'native',
        detectChanges: function () { return config.cdRef.markForCheck(); },
        rxScheduleCD: function (o) { return o.pipe(tap(function () { return markDirty(component); })); },
        scheduleCD: function () {
            markDirty(component);
            return new AbortController();
        }
    };
}
//# sourceMappingURL=native.strategy.js.map